Miscellaneous methods for the SpatialCellExperiment class that do not fit in any other documentation category.

Available methods

In the following code snippets, x and object are SpatialCellExperiment objects.

show(object):

Print a message to screen describing the contents of object.

Examples

example(SpatialCellExperiment, echo=FALSE) # Using the class example show(sce)
#> class: SpatialCellExperiment #> dim: 200 100 #> metadata(0): #> assays(2): counts logcounts #> rownames: NULL #> rowData names(0): #> colnames: NULL #> colData names(0): #> reducedDimNames(0): #> spikeNames(0): #> altExpNames(0): #> spatialDim(3): x y z